@@ -55,6 +55,7 @@
 #include <sys/types.h>
 #include <sys/user.h>
 #include <sys/socket.h>
+#include <sys/mman.h>
 
 #include "uip_arp.h"
 #include "nic.h"
@@ -65,6 +66,7 @@
 #include "cnic.h"
 #include "iscsi_if.h"
 #include "ipv6_ndpc.h"
+#include "qedi.h"
 
 /*******************************************************************************
  * Constants
@@ -81,6 +83,13 @@ const char bnx2i_library_transport_name[] = "bnx2i";
 const size_t bnx2i_library_transport_name_size =
 			sizeof(bnx2i_library_transport_name);
 
+/*******************************************************************************
+ * Constants for qedi module
+ ******************************************************************************/
+const char qedi_library_transport_name[] = "qedi";
+const size_t qedi_library_transport_name_size =
+			sizeof(qedi_library_transport_name);
+
 /******************************************************************************
  * Netlink Functions
  ******************************************************************************/
@@ -132,6 +141,7 @@ static int cnic_arp_send(nic_t *nic, nic_interface_t *nic_iface, int fd,
 	memcpy(&addr.s_addr, &dst_ip, sizeof(addr.s_addr));
 	LOG_DEBUG(PFX "%s: Sent cnic arp request for IP: %s",
 		  nic->log_name, addr_str);
+	pthread_mutex_unlock(&nic->xmit_mutex);
 
 	return 0;
 }
@@ -195,6 +205,8 @@ static int cnic_neigh_soliciation_send(nic_t *nic,
 	LOG_DEBUG(PFX "%s: Sent cnic ICMPv6 neighbor request %s",
 		  nic->log_name, addr_str);
 
+	pthread_mutex_unlock(&nic->xmit_mutex);
+
 	return 0;
 }
 
@@ -424,9 +436,6 @@ done:
 		rc = -EIO;
 	}
 
-	if (status != 0 || rc != 0)
-		pthread_mutex_unlock(&nic->xmit_mutex);
-
 	if (ev) {
 		cnic_nl_neigh_rsp(nic, fd, ev, path, mac_addr,
 				  nic_iface, status, AF_INET);
@@ -623,9 +632,6 @@ done:
 		rc = -EIO;
 	}
 
-	if (status != 0 || rc != 0)
-		pthread_mutex_unlock(&nic->xmit_mutex);
-
 	if (ev) {
 		cnic_nl_neigh_rsp(nic, fd, ev, path, mac_addr,
 				  nic_iface, status, AF_INET6);
